<?php
/**
 * Counter Section options
 *
 * @package Theme Palace
 * @subpackage Travel Life Pro
 * @since Travel Life Pro 1.0.0
 */

// Add Counter section
$wp_customize->add_section( 'travel_life_pro_counter_section', array(
	'title'             => esc_html__( 'Counter','travel-life-pro' ),
	'description'       => esc_html__( 'Counter Section options.', 'travel-life-pro' ),
	'panel'             => 'travel_life_pro_front_page_panel',
	'active_callback'	=> 'travel_life_pro_is_first_second_third_fourth_fifth_design_enable',
) );

// Counter content enable control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[counter_section_enable]', array(
	'default'			=> 	$options['counter_section_enable'],
	'sanitize_callback' => 'travel_life_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Life_Pro_Switch_Control( $wp_customize, 'travel_life_pro_theme_options[counter_section_enable]', array(
	'label'             => esc_html__( 'Counter Section Enable', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_counter_section',
	'on_off_label' 		=> travel_life_pro_switch_options(),
) ) );

// counter number control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[counter_count]', array(
	'default'          	=> $options['counter_count'],
	'sanitize_callback' => 'travel_life_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[counter_count]', array(
	'label'             => esc_html__( 'Number of Counter', 'travel-life-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_counter_section',
	'active_callback'   => 'travel_life_pro_is_counter_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['counter_count']; $i++ ) :

	if ($options['home_layout']!='default-design') {

		$wp_customize->add_setting( 'travel_life_pro_theme_options[counter_content_icon_' . $i . ']', array(
	        'sanitize_callback' => 'sanitize_text_field',
	    ) );

	    $wp_customize->add_control( new Travel_Life_Pro_Icon_Picker( $wp_customize, 'travel_life_pro_theme_options[counter_content_icon_' . $i . ']', array(
	        'label'             => sprintf( esc_html__( 'Select Icon %d', 'travel-life-pro' ), $i ),
	        'section'           => 'travel_life_pro_counter_section',
	        'active_callback'   => 'travel_life_pro_is_counter_section_enable',
	    ) ) );
	}

	// counter custom date
	$wp_customize->add_setting( 'travel_life_pro_theme_options[counter_text_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'travel_life_pro_theme_options[counter_text_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Title %d', 'travel-life-pro' ), $i ),
		'section'           => 'travel_life_pro_counter_section',
		'active_callback'	=> 'travel_life_pro_is_counter_section_enable',
	) );

	// counter custom button
	$wp_customize->add_setting( 'travel_life_pro_theme_options[counter_value_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'travel_life_pro_theme_options[counter_value_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Value %d', 'travel-life-pro' ), $i ),
		'section'           => 'travel_life_pro_counter_section',
		'active_callback'	=> 'travel_life_pro_is_counter_section_enable',
	) );

	// Separator setting
	$wp_customize->add_setting( 'travel_life_pro_theme_options[counter_separator_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( new Travel_Life_Pro_Note_Control( $wp_customize, 'travel_life_pro_theme_options[counter_separator_' . $i . ']', array(
		'section'           => 'travel_life_pro_counter_section',
		'active_callback'	=> 'travel_life_pro_is_counter_section_enable',
		'type'				=> 'custom-html',
	) ) );
endfor;