<?php
/**
 * most_view Section options
 *
 * @package Theme Palace
 * @subpackage Travel Life Pro
 * @since Travel Life Pro 1.0.0
 */

// Add most_view section
$wp_customize->add_section( 'travel_life_pro_most_view_section', array(
	'title'             => esc_html__( 'Most Viewed','travel-life-pro' ),
	'panel'             => 'travel_life_pro_front_page_panel',
	'active_callback'	=> 'travel_life_pro_is_sixth_design_enable',
) );

// most_view content enable control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[most_view_section_enable]', array(
	'default'			=> 	$options['most_view_section_enable'],
	'sanitize_callback' => 'travel_life_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Life_Pro_Switch_Control( $wp_customize, 'travel_life_pro_theme_options[most_view_section_enable]', array(
	'label'             => esc_html__( 'Most Viewed Section Enable', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_most_view_section',
	'on_off_label' 		=> travel_life_pro_switch_options(),
) ) );

	// most_view title setting and control
	$wp_customize->add_setting( 'travel_life_pro_theme_options[most_view_title]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['most_view_title'],
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'travel_life_pro_theme_options[most_view_title]', array(
		'label'           	=> esc_html__( 'Title', 'travel-life-pro' ),
		'section'        	=> 'travel_life_pro_most_view_section',
		'active_callback' 	=> 'travel_life_pro_is_most_view_section_enable',
		'type'				=> 'text',
	) );

	// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'travel_life_pro_theme_options[most_view_title]', array(
			'selector'            => '#magazine-most-viewed-posts h2.section-title',
			'settings'            => 'travel_life_pro_theme_options[most_view_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'travel_life_pro_most_view_title_partial',
			) );
	}


	// most_view content type control and setting
	$wp_customize->add_setting( 'travel_life_pro_theme_options[most_view_content_type]', array(
		'default'          	=> $options['most_view_content_type'],
		'sanitize_callback' => 'travel_life_pro_sanitize_select',
	) );

	$wp_customize->add_control( 'travel_life_pro_theme_options[most_view_content_type]', array(
		'label'             => esc_html__( 'Content Type', 'travel-life-pro' ),
		'section'           => 'travel_life_pro_most_view_section',
		'type'				=> 'select',
		'active_callback' 	=> 'travel_life_pro_is_most_view_section_enable',
		'choices'			=> array( 
			'page' 		=> esc_html__( 'Page', 'travel-life-pro' ),
			'post' 		=> esc_html__( 'Post', 'travel-life-pro' ),
			'category' 	=> esc_html__( 'Category', 'travel-life-pro' ),
			'recent' 	=> esc_html__( 'Recent', 'travel-life-pro' ),
		),
	) );

	// Event social icons number control and setting
	$wp_customize->add_setting( 'travel_life_pro_theme_options[most_view_count]', array(
		'default'          	=> $options['most_view_count'],
		'sanitize_callback' => 'travel_life_pro_sanitize_number_range',
		'validate_callback' => 'travel_life_pro_validate_most_view_count',
	) );

	$wp_customize->add_control( 'travel_life_pro_theme_options[most_view_count]', array(
		'label'             => esc_html__( 'Number of Posts', 'travel-life-pro' ),
		'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'travel-life-pro' ),
		'section'           => 'travel_life_pro_most_view_section',
		'active_callback'   => 'travel_life_pro_is_most_view_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 2,
			'max'	=> 12,
			'style' => 'width: 100px;'
			),
	) );

	for ( $i = 1; $i <= $options['most_view_count']; $i++ ) :
		// most_view pages drop down chooser control and setting
		$wp_customize->add_setting( 'travel_life_pro_theme_options[most_view_content_page_' . $i . ']', array(
			'sanitize_callback' => 'travel_life_pro_sanitize_page',
		) );

		$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[most_view_content_page_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Page %d', 'travel-life-pro' ), $i ),
			'section'           => 'travel_life_pro_most_view_section',
			'choices'			=> travel_life_pro_page_choices(),
			'active_callback'	=> 'travel_life_pro_is_most_view_section_content_page_enable',
		) ) );

		// most_view posts drop down chooser control and setting
		$wp_customize->add_setting( 'travel_life_pro_theme_options[most_view_content_post_' . $i . ']', array(
			'sanitize_callback' => 'travel_life_pro_sanitize_page',
		) );

		$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[most_view_content_post_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Post %d', 'travel-life-pro' ), $i ),
			'section'           => 'travel_life_pro_most_view_section',
			'choices'			=> travel_life_pro_post_choices(),
			'active_callback'	=> 'travel_life_pro_is_most_view_section_content_post_enable',
		) ) );
	endfor;

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'travel_life_pro_theme_options[most_view_content_category]', array(
		'sanitize_callback' => 'travel_life_pro_sanitize_single_category',
	) ) ;

	$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Taxonomy_Control( $wp_customize,'travel_life_pro_theme_options[most_view_content_category]', array(
		'label'             => esc_html__( 'Select Category', 'travel-life-pro' ),
		'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travel-life-pro' ),
		'section'           => 'travel_life_pro_most_view_section',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'travel_life_pro_is_most_view_section_content_category_enable'
	) ) );

	// Add dropdown categories setting and control.
	$wp_customize->add_setting( 'travel_life_pro_theme_options[most_view_category_exclude]', array(
		'sanitize_callback' => 'travel_life_pro_sanitize_category_list',
	) ) ;

	$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Category_Control( $wp_customize,'travel_life_pro_theme_options[most_view_category_exclude]', array(
		'label'             => esc_html__( 'Select Excluding Categories', 'travel-life-pro' ),
		'description'      	=> esc_html__( 'Note: Select categories to exclude. Press Shift key select multilple categories.', 'travel-life-pro' ),
		'section'           => 'travel_life_pro_most_view_section',
		'type'              => 'dropdown-categories',
		'active_callback'	=> 'travel_life_pro_is_most_view_section_content_most_view_enable'
	) ) );
