<?php
/**
 * Package Section options
 *
 * @package Theme Palace
 * @subpackage Travel Life Pro
 * @since Travel Life Pro 1.0.0
 */
$section_title = esc_html__( 'Package','travel-life-pro' );
$section_description = esc_html__( 'Package Section options.', 'travel-life-pro' );

if ( $options['home_layout'] !== 'pro-design') {
	$section_title = esc_html__( 'Our Team','travel-life-pro' );
	$section_description = esc_html__( 'Our Team Section options.', 'travel-life-pro' );
}
// Add Package section
$wp_customize->add_section( 'travel_life_pro_package_section', array(
	'title'             => $section_title,
	'description'       => $section_description,
	'panel'             => 'travel_life_pro_front_page_panel',
	'active_callback'	=> 'travel_life_pro_is_first_second_third_fifth_design_enable',
) );

// Package content enable control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[package_section_enable]', array(
	'default'			=> 	$options['package_section_enable'],
	'sanitize_callback' => 'travel_life_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Life_Pro_Switch_Control( $wp_customize, 'travel_life_pro_theme_options[package_section_enable]', array(
	'label'             => esc_html__( 'Package Section Enable', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_package_section',
	'on_off_label' 		=> travel_life_pro_switch_options(),
) ) );

// package title setting and control
$wp_customize->add_setting( 'travel_life_pro_theme_options[package_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['package_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[package_title]', array(
	'label'           	=> esc_html__( 'Title', 'travel-life-pro' ),
	'section'        	=> 'travel_life_pro_package_section',
	'active_callback' 	=> 'travel_life_pro_is_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_life_pro_theme_options[package_title]', array(
		'selector'            => '#top-destinations .section-header h2.section-title',
		'settings'            => 'travel_life_pro_theme_options[package_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_life_pro_package_title_partial',
    ) );
}

if ($options['home_layout'] =='pro-design') {

// package title setting and control
$wp_customize->add_setting( 'travel_life_pro_theme_options[package_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['package_sub_title'],
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[package_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'travel-life-pro' ),
	'section'        	=> 'travel_life_pro_package_section',
	'active_callback' 	=> 'travel_life_pro_is_package_section_enable',
	'type'				=> 'text',
) );

}


// Event social icons number control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[package_count]', array(
	'default'          	=> $options['package_count'],
	'sanitize_callback' => 'travel_life_pro_sanitize_number_range',
	'validate_callback' => 'travel_life_pro_validate_package_count',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[package_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'travel-life-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_package_section',
	'active_callback'   => 'travel_life_pro_is_package_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Package content type control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[package_content_type]', array(
	'default'          	=> $options['package_content_type'],
	'sanitize_callback' => 'travel_life_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[package_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_package_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_life_pro_is_package_section_enable',
	'choices'			=> travel_life_pro_package_content_type(),
) );
if ($options['home_layout'] !='pro-design') {

	// Package content type control and setting
	$wp_customize->add_setting( 'travel_life_pro_theme_options[package_content_type]', array(
		'default'          	=> $options['package_content_type'],
		'sanitize_callback' => 'travel_life_pro_sanitize_select',
	) );

	$wp_customize->add_control( 'travel_life_pro_theme_options[package_content_type]', array(
		'label'             => esc_html__( 'Content Type', 'travel-life-pro' ),
		'section'           => 'travel_life_pro_package_section',
		'type'				=> 'select',
		'active_callback' 	=> 'travel_life_pro_is_package_section_enable',
		'choices'			=> travel_life_pro_business_package_content_type(),
	) );
}

if ($options['home_layout'] == 'pro-design') {
	for ( $i = 1; $i <= $options['package_count']; $i++ ) { 
		// Add dropdown category setting and control.
		$wp_customize->add_setting(  'travel_life_pro_theme_options[package_cat_' . $i . ']', array(
			'sanitize_callback' => 'absint',
		) ) ;

		$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_life_pro_theme_options[package_cat_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select category %d', 'travel-life-pro' ), $i ),
			'description'      	=> esc_html__( 'Note: Selected category\'s no of posts will be shown from selected category', 'travel-life-pro' ),
			'section'           => 'travel_life_pro_package_section',
			'type'              => 'dropdown-categories',
			'active_callback'	=> 'travel_life_pro_is_package_section_content_category_enable'
		) ) );

		// Add dropdown destinations setting and control.
		$wp_customize->add_setting(  'travel_life_pro_theme_options[package_destinations_' . $i . ']', array(
			'sanitize_callback' => 'absint',
		) ) ;

		$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_life_pro_theme_options[package_destinations_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select destinations %d', 'travel-life-pro' ), $i ),
			'description'      	=> esc_html__( 'Note: Selected destination\'s no of posts will be shown from selected category', 'travel-life-pro' ),
			'section'           => 'travel_life_pro_package_section',
			'type'              => 'dropdown-taxonomies',
			'taxonomy'			=> 'travel_locations',
			'active_callback'	=> 'travel_life_pro_is_package_section_content_destination_enable'
		) ) );

		// Add dropdown destinations setting and control.
		$wp_customize->add_setting(  'travel_life_pro_theme_options[package_trip_' . $i . ']', array(
			'sanitize_callback' => 'absint',
		) ) ;

		$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_life_pro_theme_options[package_trip_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select trip type %d', 'travel-life-pro' ), $i ),
			'description'      	=> esc_html__( 'Note: Selected trip type\'s no of posts will be shown from selected category', 'travel-life-pro' ),
			'section'           => 'travel_life_pro_package_section',
			'type'              => 'dropdown-taxonomies',
			'taxonomy'			=> 'itinerary_types',
			'active_callback'	=> 'travel_life_pro_is_package_section_content_trip_types_enable'
		) ) );

		// package image setting and control.
		$wp_customize->add_setting( 'travel_life_pro_theme_options[package_image_' . $i . ']', array(
			'sanitize_callback' => 'travel_life_pro_sanitize_image'
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'travel_life_pro_theme_options[package_image_' . $i . ']',
				array(
				'label'       		=> sprintf( esc_html__( 'Image %d', 'travel-life-pro' ), $i ),
				'section'     		=> 'travel_life_pro_package_section',
				'active_callback'	=> 'travel_life_pro_is_package_section_enable',
		) ) );

	}
}


if ($options['home_layout'] != 'pro-design') {
	for ( $i = 1; $i <= $options['package_count']; $i++ ) {
		// package pages drop down chooser control and setting
		$wp_customize->add_setting( 'travel_life_pro_theme_options[package_content_page_' . $i . ']', array(
			'sanitize_callback' => 'travel_life_pro_sanitize_page',
		) );

		$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[package_content_page_' . $i . ']', array(
			'label'             => sprintf ( esc_html__( 'Select Page %d', 'travel-life-pro' ), $i ),
			'section'           => 'travel_life_pro_package_section',
			'choices'			=> travel_life_pro_page_choices(),
			'active_callback'	=> 'travel_life_pro_is_package_section_content_page_enable',
		) ) );

		// package posts drop down chooser control and setting
		$wp_customize->add_setting( 'travel_life_pro_theme_options[package_content_post_' . $i . ']', array(
			'sanitize_callback' => 'travel_life_pro_sanitize_page',
		) );

		$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[package_content_post_' . $i . ']', array(
			'label'             => sprintf ( esc_html__( 'Select posts %d', 'travel-life-pro' ), $i ),
			'section'           => 'travel_life_pro_package_section',
			'choices'			=> travel_life_pro_post_choices(),
			'active_callback'	=> 'travel_life_pro_is_package_section_content_post_enable',
		) ) );

		// package social
		$wp_customize->add_setting( 'travel_life_pro_theme_options[package_social_' . $i. ']', array(
			'sanitize_callback' => 'esc_url_raw',
		) );

		$wp_customize->add_control( new Travel_Life_Pro_Multi_Input_Custom_Control( $wp_customize, 'travel_life_pro_theme_options[package_social_' . $i. ']', array(
			'label'             => esc_html__( 'Social ', 'travel-life-pro' ),
			'button_text'       => esc_html__( 'Add social.', 'travel-life-pro' ),
			'section'           => 'travel_life_pro_package_section',
			'active_callback' 	=> 'travel_life_pro_is_package_section_enable',
		) ) );
	}

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'travel_life_pro_theme_options[package_content_cat]', array(
		'sanitize_callback' => 'travel_life_pro_sanitize_single_category',
	) ) ;

	$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Taxonomy_Control( $wp_customize,'travel_life_pro_theme_options[package_content_cat]', array(
		'label'             => esc_html__( 'Select Category', 'travel-life-pro' ),
		'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travel-life-pro' ),
		'section'           => 'travel_life_pro_package_section',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'travel_life_pro_is_package_section_content_cat_enable'
	) ) );
}

// package title setting and control
$wp_customize->add_setting( 'travel_life_pro_theme_options[package_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['package_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[package_btn_title]', array(
	'label'           	=> esc_html__( 'Read More Text', 'travel-life-pro' ),
	'section'        	=> 'travel_life_pro_package_section',
	'active_callback' 	=> 'travel_life_pro_is_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_life_pro_theme_options[package_btn_title]', array(
		'selector'            => '#top-destinations .read-more a.btn',
		'settings'            => 'travel_life_pro_theme_options[package_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_life_pro_package_btn_title_partial',
    ) );
}
 