<?php
/**
 * Popular Destination Section options
 *
 * @package Theme Palace
 * @subpackage Travel Life Pro
 * @since Travel Life Pro 1.0.0
 */

$section_title = esc_html__( 'Popular Destination','travel-life-pro' );
$section_description = esc_html__( 'Popular Destination Section options.', 'travel-life-pro' );

if ( $options['home_layout'] == 'second-design') {
	$section_title = esc_html__( 'Our Service','travel-life-pro' );
	$section_description = esc_html__( 'Our Service Section options.', 'travel-life-pro' );
}

if ( $options['home_layout'] == 'third-design') {
	$section_title = esc_html__( 'Our Course','travel-life-pro' );
	$section_description = esc_html__( 'Our Course Section options.', 'travel-life-pro' );
}

// Add Popular Destination section
$wp_customize->add_section( 'travel_life_pro_popular_destination_section', array(
	'title'             => $section_title,
	'description'       => $section_description,
	'panel'             => 'travel_life_pro_front_page_panel',
	'active_callback'	=> 'travel_life_pro_is_first_second_third_fifth_design_enable',
) );

// Popular Destination content enable control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[popular_destination_section_enable]', array(
	'default'			=> 	$options['popular_destination_section_enable'],
	'sanitize_callback' => 'travel_life_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Life_Pro_Switch_Control( $wp_customize, 'travel_life_pro_theme_options[popular_destination_section_enable]', array(
	'label'             => esc_html__( 'Popular Destination Section Enable', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_popular_destination_section',
	'on_off_label' 		=> travel_life_pro_switch_options(),
) ) );

// popular destination title setting and control
$wp_customize->add_setting( 'travel_life_pro_theme_options[popular_destination_title]', array(
	'default'			=> $options['popular_destination_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[popular_destination_title]', array(
	'label'           	=> esc_html__( 'Title', 'travel-life-pro' ),
	'section'        	=> 'travel_life_pro_popular_destination_section',
	'active_callback' 	=> 'travel_life_pro_is_popular_destination_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_life_pro_theme_options[popular_destination_title]', array(
		'selector'            => '#best-destinations .section-header h2.section-title',
		'settings'            => 'travel_life_pro_theme_options[popular_destination_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_life_pro_popular_destination_title_partial',
    ) );
}

// popular destination subtitle setting and control
$wp_customize->add_setting( 'travel_life_pro_theme_options[popular_destination_subtitle]', array(
	'default'			=> $options['popular_destination_subtitle'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[popular_destination_subtitle]', array(
	'label'           	=> esc_html__( 'Title', 'travel-life-pro' ),
	'section'        	=> 'travel_life_pro_popular_destination_section',
	'active_callback' 	=> 'travel_life_pro_is_popular_destination_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_life_pro_theme_options[popular_destination_subtitle]', array(
		'selector'            => '#best-destinations .section-header p.section-subtitle',
		'settings'            => 'travel_life_pro_theme_options[popular_destination_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_life_pro_popular_destination_subtitle_partial',
    ) );
}

// popular destination title setting and control
$wp_customize->add_setting( 'travel_life_pro_theme_options[popular_destination_read_more]', array(
	'default'			=> $options['popular_destination_read_more'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[popular_destination_read_more]', array(
	'label'           	=> esc_html__( 'Read More Text', 'travel-life-pro' ),
	'section'        	=> 'travel_life_pro_popular_destination_section',
	'active_callback' 	=> 'travel_life_pro_is_popular_destination_section_enable',
	'type'				=> 'text',
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[popular_destination_count]', array(
	'default'          	=> $options['popular_destination_count'],
	'sanitize_callback' => 'travel_life_pro_sanitize_number_range',
	'validate_callback' => 'travel_life_pro_validate_popular_destination_count',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[popular_destination_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'travel-life-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_popular_destination_section',
	'active_callback'   => 'travel_life_pro_is_popular_destination_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Popular Destination content type control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[popular_destination_content_type]', array(
	'default'          	=> $options['popular_destination_content_type'],
	'sanitize_callback' => 'travel_life_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[popular_destination_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_popular_destination_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_life_pro_is_popular_destination_section_enable',
	'choices'			=> travel_life_pro_popular_destination_content_type(),
) );

for ( $i=1; $i <= $options['popular_destination_count']; $i++ ) { 
	// popular_destination pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_life_pro_theme_options[popular_destination_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_life_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[popular_destination_content_page_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Page %d', 'travel-life-pro' ), $i ),
		'section'           => 'travel_life_pro_popular_destination_section',
		'choices'			=> travel_life_pro_page_choices(),
		'active_callback'	=> 'travel_life_pro_is_popular_destination_section_content_page_enable',
	) ) );

	// popular_destination posts drop down chooser control and setting
	$wp_customize->add_setting( 'travel_life_pro_theme_options[popular_destination_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travel_life_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[popular_destination_content_post_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select posts %d', 'travel-life-pro' ), $i ),
		'section'           => 'travel_life_pro_popular_destination_section',
		'choices'			=> travel_life_pro_post_choices(),
		'active_callback'	=> 'travel_life_pro_is_popular_destination_section_content_post_enable',
	) ) );

	// popular_destination trips drop down chooser control and setting
	$wp_customize->add_setting( 'travel_life_pro_theme_options[popular_destination_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'travel_life_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[popular_destination_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'travel-life-pro' ), $i ),
		'section'           => 'travel_life_pro_popular_destination_section',
		'choices'			=> travel_life_pro_trip_choices(),
		'active_callback'	=> 'travel_life_pro_is_popular_destination_section_content_trip_enable',
	) ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_life_pro_theme_options[popular_destination_content_category]', array(
	'sanitize_callback' => 'travel_life_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_life_pro_theme_options[popular_destination_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travel-life-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_popular_destination_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_life_pro_is_popular_destination_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_life_pro_theme_options[popular_destination_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_life_pro_theme_options[popular_destination_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_popular_destination_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_life_pro_is_popular_destination_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_life_pro_theme_options[popular_destination_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_life_pro_theme_options[popular_destination_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_popular_destination_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_life_pro_is_popular_destination_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_life_pro_theme_options[popular_destination_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_life_pro_theme_options[popular_destination_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_popular_destination_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_life_pro_is_popular_destination_section_content_destination_enable'
) ) );

// destination btn title setting and control
$wp_customize->add_setting( 'travel_life_pro_theme_options[popular_destination_btn_title]', array(
	'default'			=> $options['popular_destination_btn_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[popular_destination_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'travel-life-pro' ),
	'section'        	=> 'travel_life_pro_popular_destination_section',
	'active_callback' 	=> 'travel_life_pro_is_popular_destination_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_life_pro_theme_options[popular_destination_btn_title]', array(
		'selector'            => '#best-destinations .more-link a',
		'settings'            => 'travel_life_pro_theme_options[popular_destination_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_life_pro_popular_destination_btn_title_partial',
    ) );
}

// destination btn url setting and control
$wp_customize->add_setting( 'travel_life_pro_theme_options[popular_destination_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[popular_destination_btn_url]', array(
	'label'           	=> esc_html__( 'Button Link', 'travel-life-pro' ),
	'section'        	=> 'travel_life_pro_popular_destination_section',
	'active_callback' 	=> 'travel_life_pro_is_popular_destination_section_enable',
	'type'				=> 'url',
) );