<?php
/**
 * product_collection Section options
 *
 * @package Theme Palace
 * @subpackage Travel Life Pro
 * @since Travel Life Pro 1.0.0
 */
// Add product_collection section
$wp_customize->add_section( 'travel_life_pro_product_collection_section', array(
	'title'             => esc_html__( 'Product Collection','travel-life-pro' ),
	'description'       => esc_html__( 'Product Collection Section options.', 'travel-life-pro' ),
	'panel'             => 'travel_life_pro_front_page_panel',
	'active_callback'   => 'travel_life_pro_is_fourth_design_enable',
) );

// product_collection content enable control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[product_collection_section_enable]', array(
	'default'			=> 	$options['product_collection_section_enable'],
	'sanitize_callback' => 'travel_life_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Life_Pro_Switch_Control( $wp_customize, 'travel_life_pro_theme_options[product_collection_section_enable]', array(
	'label'             => esc_html__( ' Section Enable', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_product_collection_section',
	'on_off_label' 		=> travel_life_pro_switch_options(),
) ) );

// product_category title setting and control
$wp_customize->add_setting( 'travel_life_pro_theme_options[product_collection_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['product_collection_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[product_collection_title]', array(
    'label'             => esc_html__( 'Title', 'travel-life-pro' ),
    'section'           => 'travel_life_pro_product_collection_section',
    'active_callback'   => 'travel_life_pro_is_product_collection_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_life_pro_theme_options[product_collection_title]', array(
        'selector'            => '#products-collection .wrapper .section-header h2',
        'settings'            => 'travel_life_pro_theme_options[product_collection_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'travel_life_pro_product_collection_title_partial',
    ) );
}

// product_collection title setting and control
$wp_customize->add_setting( 'travel_life_pro_theme_options[product_collection_sub_title]', array(
    'sanitize_callback' => 'wp_kses_post',
    'default'           => $options['product_collection_sub_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[product_collection_sub_title]', array(
    'label'             => esc_html__( 'Sub Title', 'travel-life-pro' ),
    'section'           => 'travel_life_pro_product_collection_section',
    'active_callback'   => 'travel_life_pro_is_product_collection_section_enable',
    'type'              => 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_life_pro_theme_options[product_collection_sub_title]', array(
        'selector'            => '#products-collection .wrapper .section-header p',
        'settings'            => 'travel_life_pro_theme_options[product_collection_sub_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'travel_life_pro_product_collection_sub_title_partial',
    ) );
}

// product_collection content type control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[product_collection_content_type]', array(
	'default'          	=> $options['product_collection_content_type'],
	'sanitize_callback' => 'travel_life_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[product_collection_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_product_collection_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_life_pro_is_product_collection_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'travel-life-pro' ),
		'post' 		=> esc_html__( 'Post', 'travel-life-pro' ),
		'category' 	=> esc_html__( 'Category', 'travel-life-pro' ),
	),
) );

for ( $i = 1; $i <= $options['product_collection_count']; $i++ ) :
	// product_collection pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_life_pro_theme_options[product_collection_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_life_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[product_collection_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travel-life-pro' ), $i ),
		'section'           => 'travel_life_pro_product_collection_section',
		'choices'			=> travel_life_pro_page_choices(),
		'active_callback'	=> 'travel_life_pro_is_product_collection_section_content_page_enable',
	) ) );

	// product_collection posts drop down chooser control and setting
	$wp_customize->add_setting( 'travel_life_pro_theme_options[product_collection_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travel_life_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[product_collection_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'travel-life-pro' ), $i ),
		'section'           => 'travel_life_pro_product_collection_section',
		'choices'			=> travel_life_pro_post_choices(),
		'active_callback'	=> 'travel_life_pro_is_product_collection_section_content_post_enable',
	) ) );
	
    
		$wp_customize->add_setting( 'travel_life_pro_theme_options[product_collection_btn_title_'.$i.']', array(
			'sanitize_callback' => 'sanitize_text_field',
		) );

		$wp_customize->add_control( 'travel_life_pro_theme_options[product_collection_btn_title_'.$i.']', array(
			'label'           	=> sprintf( esc_html__( 'Button Label %d', 'travel-life-pro' ), $i ),
			'section'        	=> 'travel_life_pro_product_collection_section',
			'active_callback' 	=> 'travel_life_pro_is_product_collection_section_enable',
			'type'				=> 'text',
		) );


		// blog btn title setting and control
		$wp_customize->add_setting( 'travel_life_pro_theme_options[product_collection_btn_url_'.$i.']', array(
			'sanitize_callback' => 'esc_url_raw',
		) );

		$wp_customize->add_control( 'travel_life_pro_theme_options[product_collection_btn_url_'.$i.']', array(
			'label'           	=> sprintf( esc_html__( 'Button Url %d', 'travel-life-pro' ), $i ),
			'section'        	=> 'travel_life_pro_product_collection_section',
			'active_callback' 	=> 'travel_life_pro_is_product_collection_section_enable',
			'type'				=> 'url',
		) );
	


    $wp_customize->add_setting( 'travel_life_pro_theme_options[product_collection_hr_'. $i .']', array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( new Travel_Life_Pro_Customize_Horizontal_Line( $wp_customize, 'travel_life_pro_theme_options[product_collection_hr_'. $i .']',
        array(
            'section'           => 'travel_life_pro_product_collection_section',
            'active_callback'   => 'travel_life_pro_is_product_collection_section_enable',
            'type'            => 'hr'
    ) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_life_pro_theme_options[product_collection_content_category]', array(
	'sanitize_callback' => 'travel_life_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Taxonomy_Control( $wp_customize,'travel_life_pro_theme_options[product_collection_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travel-life-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_product_collection_section',
	'taxonomy'			=> 'category',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_life_pro_is_product_collection_section_content_category_enable'
) ) );