<?php
/**
 * Subscription Section options
 *
 * @package Theme Palace
 * @subpackage Travel Life Pro
 * @since Travel Life Pro 1.0.0
 */

// Add Subscription section
$wp_customize->add_section( 'travel_life_pro_subscription_section', array(
	'title'             => esc_html__( 'Subscription','travel-life-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install Jetpack Plugin and activate subscription module.', 'travel-life-pro' ),
	'panel'             => 'travel_life_pro_front_page_panel',
	'active_callback'	=> 'travel_life_pro_is_first_second_third_fourth_fifth_design_enable',
) );

// Subscription content enable control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[subscription_section_enable]', array(
	'default'			=> 	$options['subscription_section_enable'],
	'sanitize_callback' => 'travel_life_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Life_Pro_Switch_Control( $wp_customize, 'travel_life_pro_theme_options[subscription_section_enable]', array(
	'label'             => esc_html__( 'Subscription Section Enable', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_subscription_section',
	'on_off_label' 		=> travel_life_pro_switch_options(),
) ) );


// subscription title setting and control
$wp_customize->add_setting( 'travel_life_pro_theme_options[subscription_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[subscription_title]', array(
	'label'           	=> esc_html__( 'Title', 'travel-life-pro' ),
	'section'        	=> 'travel_life_pro_subscription_section',
	'active_callback' 	=> 'travel_life_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_life_pro_theme_options[subscription_title]', array(
		'selector'            => '#subscribe-now .section-header h2.section-title',
		'settings'            => 'travel_life_pro_theme_options[subscription_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_life_pro_subscription_title_partial',
    ) );
}
// subscription image setting and control.
$wp_customize->add_setting( 'travel_life_pro_theme_options[subscription_image]', array(
	'sanitize_callback' => 'travel_life_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'travel_life_pro_theme_options[subscription_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'travel-life-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'travel-life-pro' ), 1920, 520 ),
		'section'     		=> 'travel_life_pro_subscription_section',
		'active_callback'	=> 'travel_life_pro_is_subscription_section_enable',
) ) );

// subscription btn title setting and control
$wp_customize->add_setting( 'travel_life_pro_theme_options[subscription_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_btn_title'],
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[subscription_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'travel-life-pro' ),
	'section'        	=> 'travel_life_pro_subscription_section',
	'active_callback' 	=> 'travel_life_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

