<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Theme Palace
 * @subpackage Travel Life Pro
 * @since Travel Life Pro 1.0.0
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function travel_life_pro_body_classes( $classes ) {
	$options = travel_life_pro_get_theme_options();

	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}
	$classes[] = 'relative-header';

	// // Menu
	// $sticky = ( true === $options['menu_sticky'] ) ? 'menu-sticky' : '';
	// $classes[] = esc_attr( $sticky );

	// Add a class for typography
	$typography = (  $options['theme_typography'] == 'default' ) ? '' :  $options['theme_typography'];
	$classes[] = esc_attr( $typography );

	$body_typography = (  $options['body_theme_typography'] == 'default' ) ? '' :  $options['body_theme_typography'];
	$classes[] = esc_attr( $body_typography );

	// Add a class for layout

	// Add a class for sidebar
	$sidebar_position = travel_life_pro_layout();
	$sidebar = 'sidebar-1';
	if ( is_singular() || is_home() ) {
		$id = ( is_home() && ! is_front_page() ) ? get_option( 'page_for_posts' ) : get_the_id();
	  	$sidebar = get_post_meta( $id, 'travel-life-pro-selected-sidebar', true );
	  	$sidebar = ! empty( $sidebar ) ? $sidebar : 'sidebar-1';
	}
	
	
	if ( class_exists( 'WooCommerce' ) && ( is_shop() || is_product_category() || is_product_tag()|| is_product()) && ! is_active_sidebar('woocommerce-sidebar') ) {
		$classes[] = 'no-sidebar';
	} elseif ( is_active_sidebar( $sidebar ) ) {
		$classes[] = esc_attr( $sidebar_position );
	} else {
		$classes[] = 'no-sidebar';
	}

	if($options['home_layout'] == 'fourth-design'){
		$classes[] = 'woocommerce woocommerce-page';
	}

	$theme_version = ! empty( $options['theme_version'] ) ? $options['theme_version'] : '';
	$classes[]     = esc_attr( $theme_version );
	$classes[]		= esc_attr( $options['home_layout'] );

	return $classes;
}
add_filter( 'body_class', 'travel_life_pro_body_classes' );

function travel_life_pro_custom_script(){
	$options = travel_life_pro_get_theme_options();
?>
	<script type="text/javascript">
		
		jQuery(document).ready(function($) {
			<?php if ( true === $options['menu_sticky'] ) { ?> 
				  $(window).scroll(function() {
			    	
					if ($(this).scrollTop() > 1) {
			            $('body').addClass('menu-sticky');
			         
			        } else {
			            $('body').removeClass('menu-sticky');
			        }
			        	 
			    });
			<?php } ?>
			 
		});
	</script>
<?php
}

add_action( 'wp_footer', 'travel_life_pro_custom_script' );