<?php
/**
 * popular_product section
 *
 * This is the template for the content of popular_product section
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */
if ( ! function_exists( 'travel_life_pro_add_featured_product_section' ) ) :
    /**
    * Add popular_product section
    *
    *@since Stortech Pro 1.0.0
    */
    function travel_life_pro_add_featured_product_section() {
        $options = travel_life_pro_get_theme_options();
        // Check if popular_product is enabled on frontpage
        $featured_product_enable = apply_filters( 'travel_life_pro_section_status', true, 'featured_product_section_enable' );

        if ( true !== $featured_product_enable ) {
            return false;
        }
        // Get popular_product section details
        $section_details = array();
        $section_details = apply_filters( 'travel_life_pro_filter_featured_product_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render popular_product section now.
        travel_life_pro_render_featured_product_section( $section_details );
    }
endif;

if ( ! function_exists( 'travel_life_pro_get_featured_product_section_details' ) ) :
    /**
    * popular_product section details.
    *
    * @since Stortech Pro 1.0.0
    * @param array $input popular_product section details.
    */
    function travel_life_pro_get_featured_product_section_details( $input ) {
        $options = travel_life_pro_get_theme_options();

        // Content type.
        $featured_product_content_type  = $options['featured_product_content_type'];     

        $content = array();
        switch ( $featured_product_content_type ) {

                    	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= 2; $i++ ) {
                    if ( ! empty( $options['featured_product_content_page_' . $i] ) )
                        $page_ids[] = $options['featured_product_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => 2,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= 2; $i++ ) {
                    if ( ! empty( $options['featured_product_content_post_' . $i] ) )
                        $post_ids[] = $options['featured_product_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => 2,
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['featured_product_content_category'] ) ? $options['featured_product_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => 2,
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = travel_life_pro_trim_content( 20 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// popular_product section content details.
add_filter( 'travel_life_pro_filter_featured_product_section_details', 'travel_life_pro_get_featured_product_section_details' );


if ( ! function_exists( 'travel_life_pro_render_featured_product_section' ) ) :
  /**
   * Start popular_product section
   *
   * @return string popular_product content
   * @since Stortech Pro 1.0.0
   *
   */
   function travel_life_pro_render_featured_product_section( $content_details = array() ) {
        $options = travel_life_pro_get_theme_options();
        // Content type.
        $featured_product_content_type  = $options['featured_product_content_type'];  

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="travel_life_pro_featured_product_section">
             <div id="featured-products" class="relative">
                <div class="section-content clear col-2">
                <?php foreach ( $content_details as $key=>$content ): ?>

                    <article>
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image']); ?>');">
                            <div class="entry-container">
                                <?php if ($featured_product_content_type!='page') { ?>
                                    <span class="cat-links">
                                        <?php the_category( '', '', $content['id'] ); ?>
                                    </span><!-- .cat-links -->
                                <?php } ?>
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ; ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                                </div><!-- .entry-content -->

                                <?php if ( !empty( $options['featured_product_btn_label_'.($key+1).''] ) ) : ?>
                                    <div class="read-more">
                                        <a href="<?php echo esc_url($content['url']); ?>" class="btn" > <?php echo esc_html( $options['featured_product_btn_label_'.($key+1).''] ) ?></a>
                                    </div>
                                <?php endif; ?>

                            </div><!-- .entry-container -->
                        </div><!-- .featured-image -->
                    </article>

                <?php endforeach; ?>

                </div><!-- .section-content -->
            </div><!-- #featured-products -->
        </div>
       
    <?php }
endif;