<?php
/**
 * Latest Post section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage Travel Life Pro
 * @since Travel Life Pro 1.0.0
 */
if ( ! function_exists( 'travel_life_pro_add_latest_post_section' ) ) :
    /**
    * Add blog section
    *
    *@since Travel Life Pro 1.0.0
    */
    function travel_life_pro_add_latest_post_section() {
    	$options = travel_life_pro_get_theme_options();
        // Check if blog is enabled on frontpage
        $latest_post_enable = apply_filters( 'travel_life_pro_section_status', true, 'latest_post_section_enable' );

        if ( true !== $latest_post_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'travel_life_pro_filter_latest_post_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render blog section now.
        travel_life_pro_render_latest_post_section( $section_details );
    }
endif;

if ( ! function_exists( 'travel_life_pro_get_latest_post_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since Travel Life Pro 1.0.0
    * @param array $input blog section details.
    */
    function travel_life_pro_get_latest_post_section_details( $input ) {
        $options = travel_life_pro_get_theme_options();

        // Content type.
        $latest_post_content_type  = $options['latest_post_content_type'];
        $latest_post_count = ! empty( $options['latest_post_count'] ) ? $options['latest_post_count'] : 4;
        
        $content = array();
        switch ( $latest_post_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $latest_post_count; $i++ ) {
                    if ( ! empty( $options['latest_post_content_page_' . $i] ) )
                        $page_ids[] = $options['latest_post_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $latest_post_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $latest_post_count; $i++ ) {
                    if ( ! empty( $options['latest_post_content_post_' . $i] ) )
                        $post_ids[] = $options['latest_post_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $latest_post_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['latest_post_content_category'] ) ? $options['latest_post_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $latest_post_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['latest_post_category_exclude'] ) ? $options['latest_post_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $latest_post_count ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'trip':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $page_ids = array();

                for ( $i = 1; $i <= $latest_post_count; $i++ ) {
                    if ( ! empty( $options['latest_post_content_trip_' . $i] ) )
                        $page_ids[] = $options['latest_post_content_trip_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'itineraries',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $latest_post_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'trip-types':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_id = ! empty( $options['latest_post_content_trip_types'] ) ? $options['latest_post_content_trip_types'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'itinerary_types',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $latest_post_count ),
                    );                    
            break;

            case 'destination':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_id = ! empty( $options['latest_post_content_destination'] ) ? $options['latest_post_content_destination'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'travel_locations',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $latest_post_count ),
                    );                    
            break;

            case 'activity':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_id = ! empty( $options['latest_post_content_activity'] ) ? $options['latest_post_content_activity'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'activity',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $latest_post_count ),
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = travel_life_pro_trim_content( 20 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg'; 

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'travel_life_pro_filter_latest_post_section_details', 'travel_life_pro_get_latest_post_section_details' );


if ( ! function_exists( 'travel_life_pro_render_latest_post_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since Travel Life Pro 1.0.0
   *
   */
   function travel_life_pro_render_latest_post_section( $content_details = array() ) {
        $options = travel_life_pro_get_theme_options();
        $latest_post_content_type  = $options['latest_post_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="travel_life_pro_latest_post_section">
              <div id="<?php echo ($options['home_layout']=='seventh-design') ? 'blog-latest-posts' : 'latest-posts '; ?>" class="relative page-section same-background">
                <div class="wrapper">
                    <?php if ( ! empty( $options['latest_post_title'] ) ) : ?>
                        <div class="section-header">
                            <?php if ( ! empty( $options['latest_post_title'] ) ) : ?>
                                <h2 class="section-title"><?php echo esc_html( $options['latest_post_title'] ); ?></h2>
                            <?php endif; ?>
                            <?php if ( ! empty( $options['latest_post_subtitle'] && $options['home_layout']!='seventh-design' ) ) : ?>
                                <p class="section-subtitle"><?php echo esc_html( $options['latest_post_subtitle'] ); ?></p>
                            <?php endif; ?>
                        </div><!-- .section-header -->
                    <?php endif; ?>

                    <div class="section-content <?php if ($options['home_layout']!='seventh-design'): ?> archive-blog-wrapper <?php endif ?><?php echo ($options['home_layout']=='fourth-design' || $options['home_layout']=='seventh-design') ? 'col-3' : 'col-2'; ?>  clear">
                        <?php foreach ( $content_details as $content ): ?>
                            <?php if ($options['home_layout']=='seventh-design'): ?>
                                <article>
                                    <div class="blog-post-wrapper">
                                        <?php if ($latest_post_content_type !='page'): ?>
                                            <span class="cat-links">
                                                <?php the_category('','', $content['id']); ?>
                                            </span><!-- .cat-links -->
                                        <?php endif; ?>

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url($content['url']) ?>"><?php echo esc_html($content['title']) ?></a></h2>
                                        </header>

                                        <?php travel_life_pro_posted_on( $content['id'] ); ?>

                                        <div class="featured-image">
                                            <a href="<?php echo esc_url($content['url']) ?>"><img src="<?php echo esc_url($content['image']) ?>"></a>
                                        </div><!-- .featured-image -->

                                        <div class="entry-content">
                                            <p><?php echo esc_html($content['excerpt']) ?></p>
                                        </div><!-- .entry-content -->
                                        <?php if (!empty($options['latest_post_btn_title'] )): ?>
                                            <div class="read-more">
                                                <a href="<?php echo esc_url($content['url']) ?>" class="btn"><?php echo esc_html( $options['latest_post_btn_title'] ) ?> </a>
                                            </div><!-- .read-more  -->
                                        <?php endif; ?>
                                    </div><!-- .blog-post-wrapper -->
                                </article>
                            <?php endif; ?>
                            <?php if ($options['home_layout']!='seventh-design'): ?>
                                <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail">  
                                    <?php if (!empty($content['image'])): ?>
                                        <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']) ?>');">
                                            <a href="<?php echo esc_url($content['url']) ?>" class="post-thumbnail-link"></a>
                                        </div><!-- .featured-image -->
                                    <?php endif; ?>

                                    <div class="entry-container">
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url($content['url']) ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                        </header>

                                        <div class="entry-meta">
                                            <?php 
                                            if ($latest_post_content_type !== 'page') : 
                                                $taxonomy = 'category' ;
                                                if ( ! in_array( $latest_post_content_type, array( 'category', 'post', 'recent' ) ) ) {
                                                     $taxonomy = 'itinerary_types' ;
                                                }
                                            ?>

                                                <span class="cat-links">
                                                    <?php the_terms( $content['id'], $taxonomy  ); ?>
                                                </span><!-- .cat-links -->
                                            <?php endif; ?>

                                            <?php travel_life_pro_posted_on( $content['id'] ); ?>
                                        </div><!-- .entry-meta -->

                                        <div class="entry-content">
                                            <p><?php echo esc_html($content['excerpt']) ?></p>
                                        </div><!-- .entry-content -->
                                        <?php if ( ! empty( $options['latest_post_btn_title'] ) ) : ?>
                                            <div class="more-link">
                                                <a href="<a href="<?php echo esc_url($content['url']) ?>> <?php echo esc_html( $options['latest_post_btn_title'] ) ?> 
                                                    <?php echo travel_life_pro_get_svg( array( 'icon' => 'right' ) ); ?>
                                                </a>
                                            </div><!-- .more-link -->
                                        <?php endif; ?>
                                    </div><!-- .entry-container -->
                                </article>
                            <?php endif; ?>
                        <?php endforeach; ?>
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #latest-posts -->
        </div>
      

    <?php }
endif;