<?php 

/**
* most_view Section options
*
* @package Theme Palace
* @subpackage Travel Life Pro
* @since Travel Life Pro 1.0.0
*/

if ( ! function_exists( 'travel_life_pro_add_most_view_section' ) ) :
/**
* Add most_view section
*
*@since Travel Life Pro 1.0.0
*/
function travel_life_pro_add_most_view_section() {
    $options = travel_life_pro_get_theme_options();
// Check if most_view is enabled on frontpage
    $most_view_enable = apply_filters( 'travel_life_pro_section_status', true, 'most_view_section_enable' );

    if ( true !== $most_view_enable ) {
        return false;
    }
// Get most_view section details
    $section_details = array();
    $section_details = apply_filters( 'travel_life_pro_filter_most_view_section_details', $section_details );

    if ( empty( $section_details ) ) {
        return;
    }

// Render most_view section now.
    travel_life_pro_render_most_view_section( $section_details );
}
endif;

if ( ! function_exists( 'travel_life_pro_get_most_view_section_details' ) ) :
/**
* most_view section details.
*
* @since Travel Life Pro 1.0.0
* @param array $input most_view section details.
*/
function travel_life_pro_get_most_view_section_details( $input ) {
    $options = travel_life_pro_get_theme_options();

// Content type.
    $most_view_content_type  = $options['most_view_content_type'];
    $most_view_count = ! empty( $options['most_view_count'] ) ? $options['most_view_count'] : 4;

    $content = array();
    switch ( $most_view_content_type ) {

        case 'page':
        $page_ids = array();

        for ( $i = 1; $i <= $most_view_count; $i++ ) {
            if ( ! empty( $options['most_view_content_page_' . $i] ) )
                $page_ids[] = $options['most_view_content_page_' . $i];
        }

        $args = array(
            'post_type'         => 'page',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => absint( $most_view_count ),
            'orderby'           => 'post__in',
            );                    
        break;

        case 'post':
        $post_ids = array();

        for ( $i = 1; $i <= $most_view_count; $i++ ) {
            if ( ! empty( $options['most_view_content_post_' . $i] ) )
                $post_ids[] = $options['most_view_content_post_' . $i];
        }

        $args = array(
            'post_type'         => 'post',
            'post__in'          => ( array ) $post_ids,
            'posts_per_page'    => absint( $most_view_count ),
            'orderby'           => 'post__in',
            'ignore_sticky_posts'   => true,
            );                    
        break;

        case 'category':
        $cat_id = ! empty( $options['most_view_content_category'] ) ? $options['most_view_content_category'] : '';
        $args = array(
            'post_type'         => 'post',
            'posts_per_page'    => absint( $most_view_count ),
            'cat'               => absint( $cat_id ),
            'ignore_sticky_posts'   => true,
            );                    
        break;

        case 'recent':
        $cat_ids = ! empty( $options['most_view_category_exclude'] ) ? $options['most_view_category_exclude'] : array();
        $args = array(
            'post_type'         => 'post',
            'posts_per_page'    => absint( $most_view_count ),
            'category__not_in'  => ( array ) $cat_ids,
            'ignore_sticky_posts'   => true,
            );                    
        break;

        default:
        break;
    }

// Run The Loop.
    $query = new WP_Query( $args );
    if ( $query->have_posts() ) : 
        while ( $query->have_posts() ) : $query->the_post();
    $page_post['id']        = get_the_id();
    $page_post['title']     = get_the_title();
    $page_post['url']       = get_the_permalink();
    $page_post['excerpt']   = travel_life_pro_trim_content( 30 );
    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';


// Push to the main array.
    array_push( $content, $page_post );
    endwhile;
    endif;
    wp_reset_postdata();

    if ( ! empty( $content ) ) {
        $input = $content;
    }
    return $input;
}
endif;
// most_view section content details.
add_filter( 'travel_life_pro_filter_most_view_section_details', 'travel_life_pro_get_most_view_section_details' );

if ( ! function_exists( 'travel_life_pro_render_most_view_section' ) ) :
/**
* Start most_view section
*
* @return string most_view content
* @since Travel Life Pro 1.0.0
*
*/
function travel_life_pro_render_most_view_section( $content_details = array() ) {
    $options = travel_life_pro_get_theme_options();
    $most_view_content_type  = $options['most_view_content_type'];
    $column = ! empty( $options['most_view_column'] ) ? $options['most_view_column'] : 'col-3';
    $i = 1;

    if ( empty( $content_details ) ) {
        return;
    } ?>
    <div id="travel_life_pro_most_view_section">
        <div id="magazine-most-viewed-posts">
            <div class="wrapper">
            <?php if( !empty( $options['most_view_title'] ) ): ?>
                <div class="section-header">
                    <h2 class="section-title"><?php echo esc_html( $options['most_view_title'] ); ?></h2>
                </div><!-- .section-header -->
            <?php endif; ?>

                <div class="section-content col-2 clear">

                    <?php foreach ($content_details as $content): ?>

                    <article class="has-post-thumbnail">
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            <a href="<?php echo esc_url( $content['url'] ) ?>" class="post-thumbnail-link"></a>
                        </div><!-- .featured-image -->

                        <div class="entry-container">
                            <?php the_category( '', '', $content['id'] ); ?>

                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>   

                            <div class="entry-content">
                                <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->
                        </div><!-- .entry-container -->
                    </article>

                <?php endforeach; ?>

                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div>
    </div>
    

    <?php }
    endif;
    