<?php
/**
 * Popular News section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage Travel Life Pro
 * @since Travel Life Pro 1.0.0
 */
if ( ! function_exists( 'travel_life_pro_add_popular_news_section' ) ) :
    /**
    * Add blog section
    *
    *@since Travel Life Pro 1.0.0
    */
    function travel_life_pro_add_popular_news_section() {
    	$options = travel_life_pro_get_theme_options();
        // Check if blog is enabled on frontpage
        $popular_news_enable = apply_filters( 'travel_life_pro_section_status', true, 'popular_news_section_enable' );

        if ( true !== $popular_news_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'travel_life_pro_filter_popular_news_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render blog section now.
        travel_life_pro_render_popular_news_section( $section_details );
    }
endif;

if ( ! function_exists( 'travel_life_pro_get_popular_news_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since Travel Life Pro 1.0.0
    * @param array $input blog section details.
    */
    function travel_life_pro_get_popular_news_section_details( $input ) {
        $options = travel_life_pro_get_theme_options();

        // Content type.
        $popular_news_content_type  = $options['popular_news_content_type'];
        $popular_news_count = ! empty( $options['popular_news_count'] ) ? $options['popular_news_count'] : 4;
        
        $content = array();
        switch ( $popular_news_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $popular_news_count; $i++ ) {
                    if ( ! empty( $options['popular_news_content_page_' . $i] ) )
                        $page_ids[] = $options['popular_news_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $popular_news_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $popular_news_count; $i++ ) {
                    if ( ! empty( $options['popular_news_content_post_' . $i] ) )
                        $post_ids[] = $options['popular_news_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $popular_news_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['popular_news_content_category'] ) ? $options['popular_news_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $popular_news_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['popular_news_category_exclude'] ) ? $options['popular_news_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $popular_news_count ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = travel_life_pro_trim_content( 20 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg'; 

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'travel_life_pro_filter_popular_news_section_details', 'travel_life_pro_get_popular_news_section_details' );


if ( ! function_exists( 'travel_life_pro_render_popular_news_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since Travel Life Pro 1.0.0
   *
   */
   function travel_life_pro_render_popular_news_section( $content_details = array() ) {
        $options = travel_life_pro_get_theme_options();
        $popular_news_content_type  = $options['popular_news_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="travel_life_pro_popular_news_section">
            <div id="magazine-popular-posts" class="relative page-section same-background">
                <div class="wrapper">
                    <?php if (!empty($options['popular_news_title'])): ?>
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html($options['popular_news_title']) ?></h2>
                        </div><!-- .section-header -->
                    <?php endif; ?>
                    <div class="col-3 clear">
                        <?php foreach ( $content_details as $content ): ?>
                            <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail">     <div class="featured-post-item">
                                    <?php if (!empty($content['image'])): ?>
                                        <div class="featured-image">
                                            <img src="<?php echo esc_url($content['image']) ?>">
                                            <?php travel_life_pro_posted_on( $content['id'] ); ?>
                                        </div><!-- .featured-image -->
                                    <?php endif; ?>
                                    <div class="entry-container">
                                        <?php if ($popular_news_content_type != 'page'): ?>
                                            <?php the_category('','', $content['id']); ?>
                                        <?php endif; ?>

                                        
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url($content['url']) ?>"><?php echo esc_html($content['title']) ?></a></h2>
                                        </header>  

                                        <div class="entry-content">
                                            <p><?php echo esc_html($content['excerpt']) ?></p>
                                        </div><!-- .entry-content -->
                                    </div><!-- .entry-container -->
                                </div><!-- .featured-post-item -->
                            </article>
                        <?php endforeach; ?>
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #latest-posts -->
        </div>
      
    <?php }
endif;