<?php
/**
 * Slider section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage Travel Life Pro
 * @since Travel Life Pro 1.0.0
 */
if ( ! function_exists( 'travel_life_pro_add_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since Travel Life Pro 1.0.0
    */
    function travel_life_pro_add_slider_section() {
    	$options = travel_life_pro_get_theme_options();
        // Check if slider is enabled on frontpage
        $slider_enable = apply_filters( 'travel_life_pro_section_status', true, 'slider_section_enable' );

        if ( true !== $slider_enable ) {
            return false;
        }
        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'travel_life_pro_filter_slider_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render slider section now.
        travel_life_pro_render_slider_section( $section_details );
    }
endif;

if ( ! function_exists( 'travel_life_pro_get_slider_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since Travel Life Pro 1.0.0
    * @param array $input slider section details.
    */
    function travel_life_pro_get_slider_section_details( $input ) {
        $options = travel_life_pro_get_theme_options();

        // Content type.
        $slider_content_type  = $options['slider_content_type'];
        $slider_count = ! empty( $options['slider_count'] ) ? $options['slider_count'] : 3;
        
        $content = array();
        switch ( $slider_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_page_' . $i] ) )
                        $page_ids[] = $options['slider_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_post_' . $i] ) )
                        $post_ids[] = $options['slider_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['slider_content_category'] ) ? $options['slider_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $slider_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'trip':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $page_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_trip_' . $i] ) )
                        $page_ids[] = $options['slider_content_trip_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'itineraries',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'trip-types':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_id = ! empty( $options['slider_content_trip_types'] ) ? $options['slider_content_trip_types'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'itinerary_types',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $slider_count ),
                    );                    
            break;

            case 'destination':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_id = ! empty( $options['slider_content_destination'] ) ? $options['slider_content_destination'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'travel_locations',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $slider_count ),
                    );                    
            break;

            case 'activity':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_id = ! empty( $options['slider_content_activity'] ) ? $options['slider_content_activity'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'activity',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $slider_count ),
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = travel_life_pro_trim_content( 15 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// slider section content details.
add_filter( 'travel_life_pro_filter_slider_section_details', 'travel_life_pro_get_slider_section_details' );


if ( ! function_exists( 'travel_life_pro_render_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since Travel Life Pro 1.0.0
   *
   */
   function travel_life_pro_render_slider_section( $content_details = array() ) {
        $options = travel_life_pro_get_theme_options();
        $btn_label = ! empty( $options['slider_btn_label'] ) ? $options['slider_btn_label'] : esc_html__( 'Learn More', 'travel-life-pro' );
        // Content type.
        $slider_content_type  = $options['slider_content_type'];


        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="travel_life_pro_slider_section">
            <?php if ($options['home_layout'] != 'seventh-design'){ ?>
                <div id="featured-slider-section" class="slider-section">
                    <div class="featured-slider "  data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":false, "autoplay": <?php echo $options['slider_autoplay'] ? 'true' : 'false'; ?>, "draggable": true, "fade": true, "adaptiveHeight": true }'>
                        <?php foreach ( $content_details as $content ) : ?>
                            <article style="background-image:url('<?php echo esc_url( $content['image'] ); ?>');">
                                <div class="overlay"></div>
                                <div class="wrapper">
                                    <div class="featured-content-wrapper">
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                        </div><!-- .entry-content-->

                                        <div class="read-more">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-fill">
                                                <span class="screen-reader-text"><?php echo esc_html( $content['title'] ); ?></span>
                                                <?php echo esc_html( $btn_label ); ?>
                                            </a>
                                        </div><!-- .read-more -->
                                    </div><!-- .featured-content-wrapper -->
                                </div><!-- .wrapper -->
                                <?php if ( $options['slider_cloud'] == true ): ?>
                                     <img src="<?php echo esc_url( get_template_directory_uri().'/assets/uploads/cloud.png' ); ?>" class="cloud-image" >
                                <?php endif ?>
                               
                            </article>
                        <?php endforeach; ?>
                    </div><!-- .featured-slider -->  

                    <?php if ( ! empty( $options['slider_video_url'] ) && ! empty( $options['slider_video_label'] ) ) : ?>
                        <div class="video-overlay"></div>
                        <div class="popup">
                            <div class="widget widget_media_video">
                                <?php echo do_shortcode( '[video src="' . esc_url( $options['slider_video_url'] ) . '"]' ); ?>
                            </div>
                        </div><!-- .popup -->
                   <?php endif; ?>
                </div><!-- #featured-slider-section -->     
            <?php } else{ ?>
                <div id="blog-slider" class="wrapper" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":true, "autoplay": false, "draggable": true, "fade": false }'>
                     <?php foreach ( $content_details as $content ) : ?>
                         <article style="background-image:url('<?php echo esc_url( $content['image'] ); ?>');">
                            <div class="blog-slider-wrapper">
                                <?php if ($slider_content_type!='page') { ?>
                                    <span class="cat-links">
                                        <?php the_category( '', '', $content['id'] ); ?>
                                    </span><!-- .cat-links -->
                                <?php } ?>
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content-->
                                <div class="read-more">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" > <?php echo esc_html( $btn_label ); ?>
                                    </a>
                                </div><!-- .read-more -->

                            </div><!-- .blog-slider-wrapper -->
                        </article>
                    <?php endforeach; ?>
                </div><!-- #featured-slider -->
            <?php } ?>
        </div>
      
    <?php }
endif;